geom_balance_of_trade() creates a custom ggplot2 ribbon that visualizes the balance of trade by shading the area between exports and imports.
geom_balance_of_trade(
data = NULL,
mapping = NULL,
stat = StatBalanceOfTrade,
geom = GeomBalanceOfTrade,
position = "identity",
...,
na.rm = FALSE,
show.legend = NA
)A ggplot2 layer representing the balance of trade. Within the layer with be a colored ribbon and two lines and point sets representing your imports and exports
A data frame (defaults to the plot-level data)
Set of aesthetic mappings, see geom_ribbon
Stat to use (defaults to StatBalanceOfTrade)
Geom to use (defaults to GeomBalanceOfTrade)
Position adjustment
Other arguments passed on to the layer (e.g. na.rm)
If TRUE, remove NAs
Should this layer be included in the legend?